@@ -1,6 +1,7 @@
 # 3p
 import kombu
 
+from ddtrace import config
 from ddtrace.vendor import wrapt
 
 # project
@@ -10,7 +11,6 @@ from ...ext import SpanTypes
 from ...ext import kombu as kombux
 from ...pin import Pin
 from ...propagation.http import HTTPPropagator
-from ...settings import config
 from ...utils.formats import get_env
 from ...utils.wrappers import unwrap
 from .constants import DEFAULT_SERVICE
@@ -23,11 +23,14 @@ from .utils import get_routing_key_from_args
 
 # kombu default settings
 
-config._add('kombu', {
-    "service_name": config.service or get_env("kombu", "service_name", default=DEFAULT_SERVICE),
-})
+config._add(
+    "kombu",
+    {
+        "service_name": config.service or get_env("kombu", "service_name", default=DEFAULT_SERVICE),
+    },
+)
 
-propagator = HTTPPropagator()
+propagator = HTTPPropagator
 
 
 def patch():
@@ -36,17 +39,17 @@ def patch():
     This duplicated doesn't look nice. The nicer alternative is to use an ObjectProxy on top
     of Kombu. However, it means that any "import kombu.Connection" won't be instrumented.
     """
-    if getattr(kombu, '_datadog_patch', False):
+    if getattr(kombu, "_datadog_patch", False):
         return
-    setattr(kombu, '_datadog_patch', True)
+    setattr(kombu, "_datadog_patch", True)
 
     _w = wrapt.wrap_function_wrapper
     # We wrap the _publish method because the publish method:
     # *  defines defaults in its kwargs
     # *  potentially overrides kwargs with values from self
     # *  extracts/normalizes things like exchange
-    _w('kombu', 'Producer._publish', traced_publish)
-    _w('kombu', 'Consumer.receive', traced_receive)
+    _w("kombu", "Producer._publish", traced_publish)
+    _w("kombu", "Consumer.receive", traced_receive)
 
     # We do not provide a service for producer spans since they represent
     # external calls to another service.
@@ -62,17 +65,15 @@ def patch():
         app="kombu",
     ).onto(kombu.messaging.Producer)
 
-    Pin(
-        service=config.kombu['service_name'],
-        app='kombu'
-    ).onto(kombu.messaging.Consumer)
+    Pin(service=config.kombu["service_name"], app="kombu").onto(kombu.messaging.Consumer)
 
 
 def unpatch():
-    if getattr(kombu, '_datadog_patch', False):
-        setattr(kombu, '_datadog_patch', False)
-        unwrap(kombu.Producer, '_publish')
-        unwrap(kombu.Consumer, 'receive')
+    if getattr(kombu, "_datadog_patch", False):
+        setattr(kombu, "_datadog_patch", False)
+        unwrap(kombu.Producer, "_publish")
+        unwrap(kombu.Consumer, "receive")
+
 
 #
 # tracing functions
@@ -93,17 +94,14 @@ def traced_receive(func, instance, args, kwargs):
     with pin.tracer.trace(kombux.RECEIVE_NAME, service=pin.service, span_type=SpanTypes.WORKER) as s:
         s.set_tag(SPAN_MEASURED_KEY)
         # run the command
-        exchange = message.delivery_info['exchange']
+        exchange = message.delivery_info["exchange"]
         s.resource = exchange
         s.set_tag(kombux.EXCHANGE, exchange)
 
         s.set_tags(extract_conn_tags(message.channel.connection))
-        s.set_tag(kombux.ROUTING_KEY, message.delivery_info['routing_key'])
+        s.set_tag(kombux.ROUTING_KEY, message.delivery_info["routing_key"])
         # set analytics sample rate
-        s.set_tag(
-            ANALYTICS_SAMPLE_RATE_KEY,
-            config.kombu.get_analytics_sample_rate()
-        )
+        s.set_tag(ANALYTICS_SAMPLE_RATE_KEY, config.kombu.get_analytics_sample_rate())
         return func(*args, **kwargs)
 
 
@@ -123,10 +121,7 @@ def traced_publish(func, instance, args, kwargs):
         s.set_tags(extract_conn_tags(instance.channel.connection))
         s.set_metric(kombux.BODY_LEN, get_body_length_from_args(args))
         # set analytics sample rate
-        s.set_tag(
-            ANALYTICS_SAMPLE_RATE_KEY,
-            config.kombu.get_analytics_sample_rate()
-        )
+        s.set_tag(ANALYTICS_SAMPLE_RATE_KEY, config.kombu.get_analytics_sample_rate())
         # run the command
         propagator.inject(s.context, args[HEADER_POS])
         return func(*args, **kwargs)
